@@ -29,6 +29,8 @@ class TypedArray(numpy.ndarray):
             items = {"type": "string"}
         elif dt is bool or numpy.issubdtype(dt, numpy.bool_):
             items = {"type": "boolean"}
+        else:
+            items = {"type": "array"}
         field_schema.update(type="array", items=items)
 
 
